@@ -90,7 +90,7 @@ def _get_correlated_features_to_drop_chunked(
 
 
 def correlation_reducer(
-    df: pd.DataFrame, identifiers: list[Identifier]
+    df: pd.DataFrame, identifiers: list[Identifier], threshold: float
 ) -> pd.DataFrame:
     """Reduce dataframe by determining the correlation of numeric values."""
     feature_cols = set()
@@ -98,15 +98,15 @@ def correlation_reducer(
         feature_cols |= set(identifier.feature_columns)
 
     df = df.dropna(axis=1, how="all")
-    current_cols = set(_find_non_categorical_numeric_columns(df))
-    if len(current_cols) < 10000:
-        return df
+    # current_cols = set(_find_non_categorical_numeric_columns(df))
     drop_cols = set()
     if os.path.exists(_CORRELATION_REDUCER_FILE):
         with open(_CORRELATION_REDUCER_FILE, encoding="utf8") as handle:
             drop_cols = set(json.load(handle))
     else:
-        drop_cols = set(_get_correlated_features_to_drop_chunked(df))
+        drop_cols = set(
+            _get_correlated_features_to_drop_chunked(df, threshold=threshold)
+        )
         drop_cols &= feature_cols
         with open(_CORRELATION_REDUCER_FILE, "w", encoding="utf8") as handle:
             json.dump(list(drop_cols), handle)
